%% conformantSynthesisNonlinear
% conformant synthesis for nonlinear models
%
%% Syntax
%
% <html>
%        <div class="syntax">
% [W,V] = conformantSynthesisNonlinear(benchmark,measurements,Opts) <br>
%        </div>
% </html>
%
%% Description
% This function computes the model uncertainty that is required such
% that the uncertain model encloses all measurements of the real
% system. The model uncertainty consists of a set of uncertain inputs
% W and a set of measurement errors V.
%
%% Input Arguments
%
%
% <html>
% <table cellspacing="0" cellpadding="4" width="" border="1" frame="box" rules="none" class="">
% <tbody valign="top">
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            benchmark
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            name of the considered benchmark model (see;
%            "aroc/benchmarks/dynamics/...")
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            measuremnts
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            cell-array storing the measurements of the real
%            system, where each cell is a struct with the
%            following fields:
%        </p>
%        <p class="table">
% <table cellspacing="0" cellpadding="4" width="" border="1" frame="box" rules="none" class="inner">
% <tbody valign="top">
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .x
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            matrix storing the measured trajectory of the real
%            system (dimension: [n,N])
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .u
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            matrix storing the input signal corresponding to the
%            measured trajectory (dimension: [m,N-1])
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .t
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            vector storing the time points for the measured
%            trajectory (dimension: [1,N])
%        </p>
%    </td>
%    </tr>
% </tbody>
% </table>
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            Opts
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            a structure containing the algorithm settings
%        </p>
%        <p class="table">
% <table cellspacing="0" cellpadding="4" width="" border="1" frame="box" rules="none" class="inner">
% <tbody valign="top">
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .set
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            string specifying the type of set which is used to
%            represent the uncertainty.
%            [&#123;<tt>'interval'</tt>&#125; / <tt>'zonotope'</tt>]
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .group
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            number of measurements grouped together
%            [&#123;1&#125; / positive integer]
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .measErr
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            use measurement error to capture uncertainty
%            [&#123;false&#125; / true]
%        </p>
%    </td>
%    </tr>
% </tbody>
% </table>
%            -.mu       tradeoff between uncertain inputs and measurement
%            errors
%            [&#123;0.5&#125; / double between 0 and 1]
%        </p>
%    </td>
%    </tr>
% </tbody>
% </table>
% </html>
%
%% Output Arguments
%
%
% <html>
% <table cellspacing="0" cellpadding="4" width="" border="1" frame="box" rules="none" class="">
% <tbody valign="top">
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            W
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            resulting set of uncertain inputs
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            V
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            resulting set of measurement errors
%        </p>
%    </td>
%    </tr>
% </tbody>
% </table>
% </html>
%
%% See Also
% <conformantSynthesishelp.html |conformantSynthesis|>, <conformantSynthesisLinearhelp.html |conformantSynthesisLinear|>
%

%%
% <html>
%   <hr>
%   <p class="copy">&copy; 2018-2023 I6 Technische Universit&auml;t M&uuml;nchen
%        <tt class="minicdot">&#149;</tt>
%        <a href="https://tumcps.github.io/AROC/">Website</a>
%        <tt class="minicdot">&#149;</tt>
%        <a href="file:txts/LICENSE.txt">License</a>
%   </p>
% <div>
% <table>
%  <tr>
%   <td style="background-color:#ffffff; border:0; width:25%; vertical-align:middle; text-align:center">
%             <img src="img/logoAroc.png" alt="logoAroc" height="40px">
%      </td>
%   <td style="background-color:#ffffff; border:0; width:25%; vertical-align:middle; text-align:center">
%      <img src="img/logoCora.png" alt="logoCora" height="40px"></td>
%   <td style="background-color:#ffffff; border:0; width:25%; vertical-align:middle; text-align:center">
%      <img src="img/logoChair.png" alt="logoChair" height="40px"></td>
%   <td style="background-color:#ffffff; border:0; width:25%; vertical-align:middle; text-align:center">
%      <img src="img/logoTum.png" alt="logoTum" height="40px"></td>
%  </tr>
% </table>
% </div>
% </html>
