%% reachControlledLTISystem
% compute reachable sets for controlled LTI
% system
%
%% Syntax
%
% <html>
%        <div class="syntax">
% [R,auxTerm] = reachControlledLTISystem(Opts,R0,inpSets,Rpar,Rtran) <br>
%        </div>
% </html>
%
%% Description
% This function computes reachable sets for controlled linear
% time-invariant systems. We consider additional terms required for
% the multiplication of a zonotope and a interval matrix separately
% to ensure convexity of the subsequent optimization problem, because
% abs(abs(X)) terms are problematic.
%
%% Input Arguments
%
%
% <html>
% <table cellspacing="0" cellpadding="4" width="" border="1" frame="box" rules="none" class="">
% <tbody valign="top">
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            Opts
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            a structure containing following options
%        </p>
%        <p class="table">
% <table cellspacing="0" cellpadding="4" width="" border="1" frame="box" rules="none" class="inner">
% <tbody valign="top">
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .TpOrTi
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            compute reachable sets at time point only
%            (Opts.TpOrTi = <tt>'Tp'</tt>) or also the time interval
%            reachable sets (Opts.TpOrTi = <tt>'Ti'</tt>)
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .N
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            number of time-steps until safe terminal set is
%            reached starting in safe initial set
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .XKX
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            feedback matrix for the extended system
%            dynamics
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            .taylor
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            struct containing the propagation matrices for
%            the linear system
%        </p>
%    </td>
%    </tr>
% </tbody>
% </table>
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            R0
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            initial set (given by Z-matrix storing center;
%            and generators)
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            inpSets
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            multidimensional array storing the centers and
%            generators of the input correction zonotopes
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            Rpar
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            particluar solution due to uncertain inputs
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            Rtrans
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            particular solution due to constant inputs
%        </p>
%    </td>
%    </tr>
% </tbody>
% </table>
% </html>
%
%% Output Arguments
%
%
% <html>
% <table cellspacing="0" cellpadding="4" width="" border="1" frame="box" rules="none" class="">
% <tbody valign="top">
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            R
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            cell-array containing overall reachable sets
%        </p>
%    </td>
%    </tr>
%    <tr bgcolor="#F2F2F2">
%    <td>
%        <p class="table">
%            auxTerm
%        </p>
%    </td>
%    <td>
%        <p class="table">
%            cell-array containing auxiliary terms required
%            for the constraints
%        </p>
%    </td>
%    </tr>
% </tbody>
% </table>
% </html>
%
%% See Also
% <computeTermRegZonoLinSyshelp.html |computeTermRegZonoLinSys|>
%

%%
% <html>
%   <hr>
%   <p class="copy">&copy; 2018-2023 I6 Technische Universit&auml;t M&uuml;nchen
%        <tt class="minicdot">&#149;</tt>
%        <a href="https://tumcps.github.io/AROC/">Website</a>
%        <tt class="minicdot">&#149;</tt>
%        <a href="file:txts/LICENSE.txt">License</a>
%   </p>
% <div>
% <table>
%  <tr>
%   <td style="background-color:#ffffff; border:0; width:25%; vertical-align:middle; text-align:center">
%             <img src="img/logoAroc.png" alt="logoAroc" height="40px">
%      </td>
%   <td style="background-color:#ffffff; border:0; width:25%; vertical-align:middle; text-align:center">
%      <img src="img/logoCora.png" alt="logoCora" height="40px"></td>
%   <td style="background-color:#ffffff; border:0; width:25%; vertical-align:middle; text-align:center">
%      <img src="img/logoChair.png" alt="logoChair" height="40px"></td>
%   <td style="background-color:#ffffff; border:0; width:25%; vertical-align:middle; text-align:center">
%      <img src="img/logoTum.png" alt="logoTum" height="40px"></td>
%  </tr>
% </table>
% </div>
% </html>
